@@ -10,7 +10,8 @@ def register_plugin(registry: "Registry") -> None:
 
     from stactools.cli.commands import (
         add,
-        addraster,
+        add_asset,
+        add_raster,
         copy,
         create,
         info,
@@ -18,12 +19,14 @@ def register_plugin(registry: "Registry") -> None:
         lint,
         merge,
         migrate,
+        update_geometry,
         validate,
         version,
     )
 
     registry.register_subcommand(add.create_add_command)
-    registry.register_subcommand(addraster.create_addraster_command)
+    registry.register_subcommand(add_asset.create_add_asset_command)
+    registry.register_subcommand(add_raster.create_add_raster_command)
     registry.register_subcommand(copy.create_copy_command)
     registry.register_subcommand(create.create_create_item_command)
     registry.register_subcommand(copy.create_move_assets_command)
@@ -34,6 +37,7 @@ def register_plugin(registry: "Registry") -> None:
     registry.register_subcommand(merge.create_merge_command)
     registry.register_subcommand(validate.create_validate_command)
     registry.register_subcommand(version.create_version_command)
+    registry.register_subcommand(update_geometry.create_update_geometry_command)
 
     # TODO
     # registry.register_subcommand(migrate.create_migrate_command)
