@@ -1,7 +1,6 @@
-# flake8: noqa
-
 from stactools.core.add import add_item
-from stactools.core.addraster import add_raster_to_item
+from stactools.core.add_asset import add_asset_to_item
+from stactools.core.add_raster import add_raster_to_item
 from stactools.core.copy import (
     copy_catalog,
     move_all_assets,
@@ -14,6 +13,7 @@ from stactools.core.merge import merge_all_items, merge_items
 
 __all__ = [
     "add_item",
+    "add_asset_to_item",
     "add_raster_to_item",
     "copy_catalog",
     "layout_catalog",
@@ -24,4 +24,4 @@ __all__ = [
     "move_all_assets",
     "use_fsspec",
 ]
-__version__ = "0.3.1"
+__version__ = "0.4.0"
